# This file was auto-generated by Fern from our API Definition.

import typing

from .agents_create_response_group_base_template_id_item import AgentsCreateResponseGroupBaseTemplateIdItem

AgentsCreateResponseGroupBaseTemplateId = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsCreateResponseGroupBaseTemplateIdItem]],
    typing.Optional[typing.Any],
]
