# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .internal_template_group_create_manager_config import InternalTemplateGroupCreateManagerConfig


class InternalTemplateGroupCreate(UncheckedBaseModel):
    """
    Used for Letta Cloud
    """

    agent_ids: typing.List[str] = pydantic.Field()
    """
    
    """

    description: str = pydantic.Field()
    """
    
    """

    manager_config: typing.Optional[InternalTemplateGroupCreateManagerConfig] = pydantic.Field(default=None)
    """
    
    """

    project_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The associated project id.
    """

    shared_block_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    
    """

    hidden: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If set to True, the group will be hidden.
    """

    base_template_id: str = pydantic.Field()
    """
    The id of the base template.
    """

    template_id: str = pydantic.Field()
    """
    The id of the template.
    """

    deployment_id: str = pydantic.Field()
    """
    The id of the deployment.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
